@@ -54,8 +54,8 @@ pub use self::sortedmulti::SortedMultiVec;
 mod checksum;
 mod key;
 pub use self::key::{
-    DescriptorKeyParseError, DescriptorPublicKey, DescriptorSecretKey, DescriptorSinglePriv,
-    DescriptorSinglePub, DescriptorXKey, InnerXKey, Wildcard,
+    ConversionError, DescriptorKeyParseError, DescriptorPublicKey, DescriptorSecretKey,
+    DescriptorSinglePriv, DescriptorSinglePub, DescriptorXKey, InnerXKey, Wildcard,
 };
 
 /// Alias type for a map of public key to secret key
@@ -154,7 +154,7 @@ pub trait DescriptorTrait<Pk: MiniscriptKey> {
 }
 
 /// Script descriptor
-#[derive(Clone, PartialEq, Eq, PartialOrd, Ord)]
+#[derive(Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub enum Descriptor<Pk: MiniscriptKey> {
     /// A raw scriptpubkey (including pay-to-pubkey) under Legacy context
     Bare(Bare<Pk>),
